@@ -88,7 +88,7 @@ static void usage(char *prog)
 	  "usage: %s [ options ]\n"
 	  "\n"
 	  "where options are ([] shows the defaults):\n"
-	  "  -l num        loop 1=forever, n >= 2 n-times        \n"
+	  "  -l num        loop -1=forever, n >= 1 n-times       \n"
 	  "  -v num        verbosity (0,1,2)                  [1]\n"
 	  "  -b framenum   starting frame number              [0]\n"
 	  "  -f framerate  framerate for output stream (fps)     \n"
@@ -142,14 +142,13 @@ static void parse_commandline(int argc, char ** argv, parameters_t *param)
   param->interlace = Y4M_UNKNOWN;
   param->interleave = -1;
   param->verbose = 1;
-  param->loop = 0;
+  param->loop = 1;
   param->rescale_YUV = 1;
 
   /* parse options */
   for (;;) {
     if (-1 == (c = getopt(argc, argv, "I:hv:L:b:j:n:f:l:R:")))
       break;
-    mjpeg_info("Parsing char %c\n", c);
     switch (c) {
 
     case 'j':
@@ -196,8 +195,8 @@ static void parse_commandline(int argc, char ** argv, parameters_t *param)
       break;     
     case 'l':
       param->loop = atoi(optarg);
-      if  (param->loop == 0) 
-	mjpeg_error_exit1( "-l option requires a number greater than 0");    
+      if  (param->loop == 0 || param->loop < -1 ) 
+	mjpeg_error_exit1( "-l option requires a number greater than 0 or -1 to loop forever ");    
       break;     
     case 'h':
     default:
@@ -460,11 +459,10 @@ static int generate_YUV4MPEG(parameters_t *param)
    
        y4m_write_frame(STDOUT_FILENO, &streaminfo, &frameinfo, yuv);
      }
- 
-     if (param->loop != 1)
+     if (param->loop != -1)
        loops--;
  
-  } while(loops);
+  } while( loops >=1 || loops == -1 );
   
   y4m_fini_stream_info(&streaminfo);
   y4m_fini_frame_info(&frameinfo);
@@ -485,7 +483,6 @@ int main(int argc, char ** argv)
 { 
   parameters_t param;
 
-  mjpeg_info("Wp1\n");
   parse_commandline(argc, argv, &param);
   mjpeg_default_handler_verbosity(param.verbose);
 
