@@ -27,11 +27,10 @@
 #else
 #include <unistd.h>
 #endif
+#include <sys/stat.h>
 #ifdef HAVE_GETOPT_H
 #include <getopt.h>
 #endif
-#include <sys/stat.h>
-
 #include <mjpeg_logging.h>
 #include <format_codes.h>
 
@@ -77,7 +76,6 @@ MultiplexJob::MultiplexJob()
     packets_per_pack = 1;
     max_timeouts = 10;
     max_PTS = 0;
-    emul_vcdmplex = 0;
     max_segment_size = 0; // MB, default is unlimited (suitable for DVD)
     outfile_pattern = 0;
     packets_per_pack = 1;
@@ -109,7 +107,7 @@ MultiplexJob::~MultiplexJob()
 void MultiplexJob::Usage(char *str)
 {
     fprintf( stderr,
-	"mjpegtools mplex-2 version " VERSION "\n"
+	"mjpegtools mplex-2 version " VERSION " (" MPLEX_VER ")\n"
 	"Usage: %s [params] -o <output filename pattern> <input file>... \n"
 	"         %%d in the output file name is by segment count\n"
 	"  where possible params are:\n"
@@ -147,9 +145,9 @@ void MultiplexJob::Usage(char *str)
 	exit (1);
 }
 
-static const char short_options[] = "o:b:r:O:v:m:f:l:s:S:q:p:L:VXMeh";
+static const char short_options[] = "o:b:r:O:v:f:l:s:S:p:L:VMh";
 
-#if defined(HAVE_GETLONG)
+#if defined(HAVE_GETOPT_LONG)
 static struct option long_options[] = 
 {
      { "verbose",           1, 0, 'v' },
@@ -238,8 +236,8 @@ void MultiplexJob::SetFromCmdLine(unsigned int argc, char *argv[])
     int n;
     outfile_pattern = NULL;
 
-#if defined(HAVE_GETLONG)
-	while( (n=getlong(argc,argv,short_options,long_options, NULL)) != -1 )
+#if defined(HAVE_GETOPT_LONG)
+	while( (n=getopt_long(argc,argv,short_options,long_options, NULL)) != -1 )
 #else
     while( (n=getopt(argc,argv,short_options)) != -1 )
 #endif
@@ -250,12 +248,6 @@ void MultiplexJob::SetFromCmdLine(unsigned int argc, char *argv[])
             break;
 		case 'o' :
 			outfile_pattern = optarg;
-			break;
-		case 'm' :
-			mpeg = atoi(optarg);
-			if( mpeg < 1 || mpeg > 2 )
-				Usage(argv[0]);
-  	
 			break;
 		case 'v' :
 			verbose = atoi(optarg);
@@ -336,9 +328,6 @@ void MultiplexJob::SetFromCmdLine(unsigned int argc, char *argv[])
 		case 'M' :
 			multifile_segment = true;
 			break;
-		case 'e' :
-			emul_vcdmplex = 1;
-			break;
 		case '?' :
 		default :
 			Usage(argv[0]);
@@ -350,7 +339,7 @@ void MultiplexJob::SetFromCmdLine(unsigned int argc, char *argv[])
 		Usage(argv[0]);
     }
 	(void)mjpeg_default_handler_verbosity(verbose);
-	mjpeg_info( "mplex version %s (%s)",MPLEX_VER,MPLEX_DATE );
+	mjpeg_info( "mplex version %s (%s %s)",VERSION,MPLEX_VER,MPLEX_DATE );
 
     InputStreamsFromCmdLine( argc-(optind-1), argv+optind-1);
 }
