@@ -35,7 +35,6 @@ void print_settings(void);
 void turn_on_accels(void);
 void display_help(void);
 
-static uint8_t *bufalloc(size_t size);
 
 struct DNSR_GLOBAL denoiser;
 
@@ -153,6 +152,16 @@ int main(int argc, char *argv[])
       denoiser.border.h        = denoiser.frame.h;
   }
 
+  /* handle relative border height/width offsets. */
+  if ( denoiser.border.w < 0 )
+  {
+      denoiser.border.w = denoiser.frame.w - denoiser.border.x + denoiser.border.w;
+  }
+  if ( denoiser.border.h < 0 )
+  {
+      denoiser.border.h = denoiser.frame.h - denoiser.border.y + denoiser.border.h;
+  }
+
   /* stream is interlaced and shall not be
    * deinterlaced ?
    */ 
@@ -187,6 +196,9 @@ int main(int argc, char *argv[])
   /* turn on accelerations if any */
   turn_on_accels();
   
+  /* precompute luma contrast values for lookup table */
+  init_luma_contrast_vector();
+  
   /* read every single frame until the end of the input stream */
   while 
     (
@@ -240,28 +252,21 @@ int main(int argc, char *argv[])
 
 
 
-static uint8_t *bufalloc(size_t size)
-{
-  uint8_t *ret = (uint8_t *)malloc(size);
-  if( ret == NULL )
-    mjpeg_error_exit1( "Out of memory: could not allocate buffer" );
-  return ret;
-}
 
 
 
 void allc_buffers(void)
 {
-  int luma_buffsize = denoiser.frame.w * denoiser.frame.h;
-  int chroma_buffsize = denoiser.frame.Cw * denoiser.frame.Ch;
- 
+  int luma_buffsize; 
+  int chroma_buffsize;
+
   /* now, the MC-functions really(!) do go beyond the vertical
    * frame limits so we need to make the buffers larger to avoid
    * bound-checking (memory vs. speed...)
    */
   
-  luma_buffsize += 2*BUF_OFF*denoiser.frame.w;
-  chroma_buffsize += 2*BUF_COFF*denoiser.frame.Cw;
+  luma_buffsize = denoiser.frame.w * (denoiser.frame.h+2*BUF_OFF);
+  chroma_buffsize = denoiser.frame.Cw * (denoiser.frame.Ch+2*BUF_OFF);
   
   denoiser.frame.io[0] = bufalloc (luma_buffsize);
   denoiser.frame.io[1] = bufalloc (chroma_buffsize);
@@ -534,7 +539,7 @@ void turn_on_accels(void)
     deinterlace = &deinterlace_mmx;
   }
   else
-    if( (CPU_CAP & ACCEL_X86_MMX)!=0 ) /* MMX */
+    if ( (CPU_CAP & ACCEL_X86_MMX)!=0 ) /* MMX */
     {
       calc_SAD    = &calc_SAD_mmx;
       if (denoiser.frame.Cw==denoiser.frame.w/4 && denoiser.frame.Ch==denoiser.frame.h)
@@ -609,12 +614,14 @@ display_help(void)
   "                   on 4:3 (VCD and SVCD) (default=%i,%i,%i,%i)\n"
   "\n"
   "-L <0...255>       Set luminance contrast in percent. (default=%i)\n"
+  "                   100 = no effect\n"
   "\n"
   "-C <0...255>       Set chrominance contrast in percent. AKA \"Saturation\"\n"
-  "                   (default=%i)"
+  "                   (default=%i) 100 = no effect\n"
   "\n"
   "-S <0...255>       Set sharpness in percent. WARNING: do not set too high\n"
   "                   as this will gain bit-noise. (default=%i)\n"
+  "                   0 = no effect\n"
   "\n"
   "-F                 Force deinterlacing. By default denoise interlaced.\n"
   "\n"
